@@ -8,7 +8,7 @@
  *
  * General stdiodemo defines
  *
- * $Id: defines.h,v 1.1.2.2 2006/10/08 21:51:14 joerg_wunsch Exp $
+ * $Id: defines.h 2002 2009-06-25 20:21:16Z joerg_wunsch $
  */
 
 /* CPU frequency */
@@ -18,12 +18,12 @@
 #define UART_BAUD  9600
 
 /* HD44780 LCD port connections */
-#define HD44780_PORT A
-#define HD44780_RS PORT6
-#define HD44780_RW PORT4
-#define HD44780_E  PORT5
+#define HD44780_RS A, 6
+#define HD44780_RW A, 4
+#define HD44780_E  A, 5
 /* The data bits have to be in ascending order. */
-#define HD44780_D4 PORT0
-#define HD44780_D5 PORT1
-#define HD44780_D6 PORT2
-#define HD44780_D7 PORT3
+#define HD44780_D4 A, 0
+
+/* Whether to read the busy flag, or fall back to
+   worst-time delays. */
+#define USE_BUSY_BIT 1
