@@ -29,7 +29,7 @@
   POSSIBILITY OF SUCH DAMAGE. 
 */
 
-/* $Id: io90pwm2b.h,v 1.3.2.5 2008/03/19 21:05:23 arcanum Exp $ */
+/* $Id: io90pwm2b.h 1951 2009-04-25 20:41:17Z arcanum $ */
 
 /* avr/io90pwm2b.h - definitions for AT90PWM2B */
 
@@ -288,24 +288,33 @@
 #define TCNT0_7 7
 
 #define OCR0A _SFR_IO8(0x27)
-#define OCR0_0 0
-#define OCR0_1 1
-#define OCR0_2 2
-#define OCR0_3 3
-#define OCR0_4 4
-#define OCR0_5 5
-#define OCR0_6 6
-#define OCR0_7 7
+#define OCR0A_0 0
+#define OCR0A_1 1
+#define OCR0A_2 2
+#define OCR0A_3 3
+#define OCR0A_4 4
+#define OCR0A_5 5
+#define OCR0A_6 6
+#define OCR0A_7 7
 
 #define OCR0B _SFR_IO8(0x28)
-#define OCR0_0 0
-#define OCR0_1 1
-#define OCR0_2 2
-#define OCR0_3 3
-#define OCR0_4 4
-#define OCR0_5 5
-#define OCR0_6 6
-#define OCR0_7 7
+#define OCR0B_0 0
+#define OCR0B_1 1
+#define OCR0B_2 2
+#define OCR0B_3 3
+#define OCR0B_4 4
+#define OCR0B_5 5
+#define OCR0B_6 6
+#define OCR0B_7 7
+
+#define OCR0_0 0    /* Deprecated */
+#define OCR0_1 1    /* Deprecated */
+#define OCR0_2 2    /* Deprecated */
+#define OCR0_3 3    /* Deprecated */
+#define OCR0_4 4    /* Deprecated */
+#define OCR0_5 5    /* Deprecated */
+#define OCR0_6 6    /* Deprecated */
+#define OCR0_7 7    /* Deprecated */
 
 #define PLLCSR _SFR_IO8(0x29)
 #define PLOCK 0
@@ -377,7 +386,7 @@
 #define WDP0 0
 #define WDP1 1
 #define WDP2 2
-#define WDE3 3
+#define WDE 3
 #define WDCE 4
 #define WDP3 5
 #define WDIE 6
@@ -446,7 +455,10 @@
 #define AMP1IS 6
 #define AMP1EN 7
 
-#define ADC _SFR_MEM16(0x78)
+#ifndef __ASSEMBLER__
+#define ADC     _SFR_MEM16(0x78)
+#endif
+#define ADCW    _SFR_MEM16(0x78)
 
 #define ADCL _SFR_MEM8(0x78)
 #define ADCL0 0
@@ -1318,8 +1330,9 @@
 /* Memory Sizes */
 #define RAMEND         0x2FF
 #define XRAMSIZE       0
-#define XRAMEND        (RAMEND + XRAMSIZE)
+#define XRAMEND        RAMEND
 #define E2END          0x1FF
+#define E2PAGESIZE     4
 #define FLASHEND       0x1FFF
 #define SPM_PAGESIZE   32
 
@@ -1330,37 +1343,37 @@
 #define FUSE_MEMORY_SIZE 3
 
 /* Low Fuse Byte */
-#define FUSE_CKSEL0  ~_BV(0)  /* Select Clock Source */
-#define FUSE_CKSEL1  ~_BV(1)  /* Select Clock Source */
-#define FUSE_CKSEL2  ~_BV(2)  /* Select Clock Source */
-#define FUSE_CKSEL3  ~_BV(3)  /* Select Clock Source */
-#define FUSE_SUT0    ~_BV(4)  /* Select start-up time */
-#define FUSE_SUT1    ~_BV(5)  /* Select start-up time */
-#define FUSE_CKOUT   ~_BV(6) /* Oscillator output option */
-#define FUSE_CLKDIV8 ~_BV(7)  /* Divide clock by 8 */
+#define FUSE_CKSEL0  (unsigned char)~_BV(0)  /* Select Clock Source */
+#define FUSE_CKSEL1  (unsigned char)~_BV(1)  /* Select Clock Source */
+#define FUSE_CKSEL2  (unsigned char)~_BV(2)  /* Select Clock Source */
+#define FUSE_CKSEL3  (unsigned char)~_BV(3)  /* Select Clock Source */
+#define FUSE_SUT0    (unsigned char)~_BV(4)  /* Select start-up time */
+#define FUSE_SUT1    (unsigned char)~_BV(5)  /* Select start-up time */
+#define FUSE_CKOUT   (unsigned char)~_BV(6)  /* Oscillator output option */
+#define FUSE_CKDIV8  (unsigned char)~_BV(7)  /* Divide clock by 8 */
 #define LFUSE_DEFAULT (FUSE_CKSEL0 & FUSE_CKSEL2 & FUSE_CKSEL3 & FUSE_SUT0 & FUSE_CKDIV8)
 
 
 /* High Fuse Byte */
-#define FUSE_BODLEVEL0 ~_BV(0)  /* Brown-out Detector trigger level */
-#define FUSE_BODLEVEL1 ~_BV(1)  /* Brown-out Detector trigger level */
-#define FUSE_BODLEVEL2 ~_BV(2)  /* Brown out detector trigger level */
-#define FUSE_EESAVE    ~_BV(3)  /* EEPROM memory is preserved through chip erase */
-#define FUSE_WDTON     ~_BV(4)  /* Watchdog timer always on */
-#define FUSE_SPIEN     ~_BV(5)  /* Enable Serial programming and Data Downloading */
-#define FUSE_DWEN      ~_BV(6)  /* debugWIRE Enable */
-#define FUSE_RSTDISBL  ~_BV(7)  /* External Reset Disable */
+#define FUSE_BODLEVEL0 (unsigned char)~_BV(0)  /* Brown-out Detector trigger level */
+#define FUSE_BODLEVEL1 (unsigned char)~_BV(1)  /* Brown-out Detector trigger level */
+#define FUSE_BODLEVEL2 (unsigned char)~_BV(2)  /* Brown out detector trigger level */
+#define FUSE_EESAVE    (unsigned char)~_BV(3)  /* EEPROM memory is preserved through chip erase */
+#define FUSE_WDTON     (unsigned char)~_BV(4)  /* Watchdog timer always on */
+#define FUSE_SPIEN     (unsigned char)~_BV(5)  /* Enable Serial programming and Data Downloading */
+#define FUSE_DWEN      (unsigned char)~_BV(6)  /* debugWIRE Enable */
+#define FUSE_RSTDISBL  (unsigned char)~_BV(7)  /* External Reset Disable */
 #define HFUSE_DEFAULT (FUSE_SPIEN)    
 
 
 /* Extended Fuse Byte */
-#define FUSE_BOOTRST ~_BV(0)  /* Select Reset Vector */
-#define FUSE_BOOTSZ0 ~_BV(1)  /* Select Boot Size */
-#define FUSE_BOOTSZ1 ~_BV(2)  /* Select Boot Size */
-#define FUSE_PSCRV   ~_BV(4)  /* PSCOUT Reset Value */
-#define FUSE_PSC0RB  ~_BV(5)  /* PSC0 Reset Behaviour */
-#define FUSE_PSC1RB  ~_BV(6)  /* PSC1 Reset Behaviour */
-#define FUSE_PSC2RB  ~_BV(7)  /* PSC2 Reset Behaviour */
+#define FUSE_BOOTRST (unsigned char)~_BV(0)  /* Select Reset Vector */
+#define FUSE_BOOTSZ0 (unsigned char)~_BV(1)  /* Select Boot Size */
+#define FUSE_BOOTSZ1 (unsigned char)~_BV(2)  /* Select Boot Size */
+#define FUSE_PSCRV   (unsigned char)~_BV(4)  /* PSCOUT Reset Value */
+#define FUSE_PSC0RB  (unsigned char)~_BV(5)  /* PSC0 Reset Behaviour */
+#define FUSE_PSC1RB  (unsigned char)~_BV(6)  /* PSC1 Reset Behaviour */
+#define FUSE_PSC2RB  (unsigned char)~_BV(7)  /* PSC2 Reset Behaviour */
 #define EFUSE_DEFAULT (FUSE_BOOTSZ0 & FUSE_BOOTSZ1)
 
 
@@ -1370,4 +1383,10 @@
 #define __BOOT_LOCK_BITS_1_EXIST 
 
 
+/* Signature */
+#define SIGNATURE_0 0x1E
+#define SIGNATURE_1 0x93
+#define SIGNATURE_2 0x83
+
+
 #endif /* _AVR_IO90PWM2B_H_ */
