@@ -29,7 +29,7 @@
   POSSIBILITY OF SUCH DAMAGE. 
 */
 
-/* $Id: io90pwm3b.h,v 1.1.2.4 2007/12/19 00:29:18 arcanum Exp $ */
+/* $Id: io90pwm3b.h 1951 2009-04-25 20:41:17Z arcanum $ */
 
 /* avr/io90pwm3b.h - definitions for AT90PWM3B */
 
@@ -201,11 +201,13 @@
 #define INTF0 0
 #define INTF1 1
 #define INTF2 2
+#define INTF3 3
 
 #define EIMSK _SFR_IO8(0x1D)
 #define INT0 0
 #define INT1 1
 #define INT2 2
+#define INT3 3
 
 #define GPIOR0 _SFR_IO8(0x1E)
 #define GPIOR00 0
@@ -235,6 +237,8 @@
 #define EEDR6 6
 #define EEDR7 7
 
+#define EEAR _SFR_IO16(0x21)
+
 #define EEARL _SFR_IO8(0x21)
 #define EEARL0 0
 #define EEARL1 1
@@ -284,24 +288,33 @@
 #define TCNT0_7 7
 
 #define OCR0A _SFR_IO8(0x27)
-#define OCR0_0 0
-#define OCR0_1 1
-#define OCR0_2 2
-#define OCR0_3 3
-#define OCR0_4 4
-#define OCR0_5 5
-#define OCR0_6 6
-#define OCR0_7 7
+#define OCR0A_0 0
+#define OCR0A_1 1
+#define OCR0A_2 2
+#define OCR0A_3 3
+#define OCR0A_4 4
+#define OCR0A_5 5
+#define OCR0A_6 6
+#define OCR0A_7 7
 
 #define OCR0B _SFR_IO8(0x28)
-#define OCR0_0 0
-#define OCR0_1 1
-#define OCR0_2 2
-#define OCR0_3 3
-#define OCR0_4 4
-#define OCR0_5 5
-#define OCR0_6 6
-#define OCR0_7 7
+#define OCR0B_0 0
+#define OCR0B_1 1
+#define OCR0B_2 2
+#define OCR0B_3 3
+#define OCR0B_4 4
+#define OCR0B_5 5
+#define OCR0B_6 6
+#define OCR0B_7 7
+
+#define OCR0_0 0    /* Deprecated */
+#define OCR0_1 1    /* Deprecated */
+#define OCR0_2 2    /* Deprecated */
+#define OCR0_3 3    /* Deprecated */
+#define OCR0_4 4    /* Deprecated */
+#define OCR0_5 5    /* Deprecated */
+#define OCR0_6 6    /* Deprecated */
+#define OCR0_7 7    /* Deprecated */
 
 #define PLLCSR _SFR_IO8(0x29)
 #define PLOCK 0
@@ -373,7 +386,7 @@
 #define WDP0 0
 #define WDP1 1
 #define WDP2 2
-#define WDE3 3
+#define WDE 3
 #define WDCE 4
 #define WDP3 5
 #define WDIE 6
@@ -396,7 +409,6 @@
 #define PRPSC1 6
 #define PRPSC2 7
 
-
 #define OSCCAL _SFR_MEM8(0x66)
 #define CAL0 0
 #define CAL1 1
@@ -413,6 +425,8 @@
 #define ISC11 3
 #define ISC20 4
 #define ISC21 5
+#define ISC30 6
+#define ISC31 7
 
 #define TIMSK0 _SFR_MEM8(0x6E)
 #define TOIE0 0
@@ -441,7 +455,10 @@
 #define AMP1IS 6
 #define AMP1EN 7
 
-#define ADC _SFR_MEM16(0x78)
+#ifndef __ASSEMBLER__
+#define ADC     _SFR_MEM16(0x78)
+#endif
+#define ADCW    _SFR_MEM16(0x78)
 
 #define ADCL _SFR_MEM8(0x78)
 #define ADCL0 0
@@ -551,7 +568,7 @@
 #define TCNT1H6 6
 #define TCNT1H7 7
 
-#define ICR1 _SFR_MEM8(0x86)
+#define ICR1 _SFR_MEM16(0x86)
 
 #define ICR1L _SFR_MEM8(0x86)
 #define ICR1L0 0
@@ -978,8 +995,8 @@
 #define PSOC1 _SFR_MEM8(0xE0)
 #define POEN1A 0
 #define POEN1B 2
-#define PSYNC1 4
-#define PSYNC1 5
+#define PSYNC1_0 4
+#define PSYNC1_1 5
 
 #define OCR1SA _SFR_MEM16(0xE2)
 
@@ -1115,7 +1132,6 @@
 #define PICR1_11 3
 #define PCST1 7
 
-
 #define PSOC2 _SFR_MEM8(0xF0)
 #define POEN2A 0
 #define POEN2C 1
@@ -1161,7 +1177,8 @@
 #define OCR2RA_1 1
 #define OCR2RA_2 2
 #define OCR2RA_3 3
-#define OCR2RA_4 4#define OCR2RA_5 5
+#define OCR2RA_4 4
+#define OCR2RA_5 5
 #define OCR2RA_6 6
 #define OCR2RA_7 7
 
@@ -1289,7 +1306,7 @@
 #define TIMER1_COMPB_vect   _VECTOR(13)  /* Timer/Counter Compare Match B */
 /* Vector 14, Reserved */
 #define TIMER1_OVF_vect     _VECTOR(15)  /* Timer/Counter1 Overflow */
-#define TIMER0_COMP A_vect  _VECTOR(16)  /* Timer/Counter0 Compare Match A */
+#define TIMER0_COMPA_vect   _VECTOR(16)  /* Timer/Counter0 Compare Match A */
 #define TIMER0_OVF_vect     _VECTOR(17)  /* Timer/Counter0 Overflow */
 #define ADC_vect            _VECTOR(18)  /* ADC Conversion Complete */
 #define INT1_vect           _VECTOR(19)  /* External Interrupt Request 1 */
@@ -1312,8 +1329,10 @@
 
 /* Memory Sizes */
 #define RAMEND         0x2FF
-#define XRAMEND        0x00
+#define XRAMSIZE       0
+#define XRAMEND        RAMEND
 #define E2END          0x1FF
+#define E2PAGESIZE     4
 #define FLASHEND       0x1FFF
 #define SPM_PAGESIZE   32
 
@@ -1324,38 +1343,38 @@
 #define FUSE_MEMORY_SIZE 3
 
 /* Low Fuse Byte */
-#define CKSEL0  ~_BV(0)  /* Select Clock Source */
-#define CKSEL1  ~_BV(1)  /* Select Clock Source */
-#define CKSEL2  ~_BV(2)  /* Select Clock Source */
-#define CKSEL3  ~_BV(3)  /* Select Clock Source */
-#define SUT0    ~_BV(4)  /* Select start-up time */
-#define SUT1    ~_BV(5)  /* Select start-up time */
-#define CKOUT   ~_BV(6) /* Oscillator output option */
-#define CLKDIV8 ~_BV(7)  /* Divide clock by 8 */
-#define LFUSE_DEFAULT (CKSEL0 & CKSEL2 & CKSEL3 & SUT0 & CKDIV8)
+#define FUSE_CKSEL0  (unsigned char)~_BV(0)  /* Select Clock Source */
+#define FUSE_CKSEL1  (unsigned char)~_BV(1)  /* Select Clock Source */
+#define FUSE_CKSEL2  (unsigned char)~_BV(2)  /* Select Clock Source */
+#define FUSE_CKSEL3  (unsigned char)~_BV(3)  /* Select Clock Source */
+#define FUSE_SUT0    (unsigned char)~_BV(4)  /* Select start-up time */
+#define FUSE_SUT1    (unsigned char)~_BV(5)  /* Select start-up time */
+#define FUSE_CKOUT   (unsigned char)~_BV(6)  /* Oscillator output option */
+#define FUSE_CKDIV8  (unsigned char)~_BV(7)  /* Divide clock by 8 */
+#define LFUSE_DEFAULT (FUSE_CKSEL0 & FUSE_CKSEL2 & FUSE_CKSEL3 & FUSE_SUT0 & FUSE_CKDIV8)
 
 
 /* High Fuse Byte */
-#define BODLEVEL0 ~_BV(0)  /* Brown-out Detector trigger level */
-#define BODLEVEL1 ~_BV(1)  /* Brown-out Detector trigger level */
-#define BODLEVEL2 ~_BV(2)  /* Brown out detector trigger level */
-#define EESAVE    ~_BV(3)  /* EEPROM memory is preserved through chip erase */
-#define WDTON     ~_BV(4)  /* Watchdog timer always on */
-#define SPIEN     ~_BV(5)  /* Enable Serial programming and Data Downloading */
-#define DWEN      ~_BV(6)  /* debugWIRE Enable */
-#define RSTDISBL  ~_BV(7)  /* External Reset Disable */
-#define HFUSE_DEFAULT (SPIEN)    
+#define FUSE_BODLEVEL0 (unsigned char)~_BV(0)  /* Brown-out Detector trigger level */
+#define FUSE_BODLEVEL1 (unsigned char)~_BV(1)  /* Brown-out Detector trigger level */
+#define FUSE_BODLEVEL2 (unsigned char)~_BV(2)  /* Brown out detector trigger level */
+#define FUSE_EESAVE    (unsigned char)~_BV(3)  /* EEPROM memory is preserved through chip erase */
+#define FUSE_WDTON     (unsigned char)~_BV(4)  /* Watchdog timer always on */
+#define FUSE_SPIEN     (unsigned char)~_BV(5)  /* Enable Serial programming and Data Downloading */
+#define FUSE_DWEN      (unsigned char)~_BV(6)  /* debugWIRE Enable */
+#define FUSE_RSTDISBL  (unsigned char)~_BV(7)  /* External Reset Disable */
+#define HFUSE_DEFAULT (FUSE_SPIEN)    
 
 
 /* Extended Fuse Byte */
-#define BOOTRST ~_BV(0)  /* Select Reset Vector */
-#define BOOTSZ0 ~_BV(1)  /* Select Boot Size */
-#define BOOTSZ1 ~_BV(2)  /* Select Boot Size */
-#define PSCRV   ~_BV(4)  /* PSCOUT Reset Value */
-#define PSC0RB  ~_BV(5)  /* PSC0 Reset Behaviour */
-#define PSC1RB  ~_BV(6)  /* PSC1 Reset Behaviour */
-#define PSC2RB  ~_BV(7)  /* PSC2 Reset Behaviour */
-#define EFUSE_DEFAULT (BOOTSZ0 & BOOTSZ1)
+#define FUSE_BOOTRST (unsigned char)~_BV(0)  /* Select Reset Vector */
+#define FUSE_BOOTSZ0 (unsigned char)~_BV(1)  /* Select Boot Size */
+#define FUSE_BOOTSZ1 (unsigned char)~_BV(2)  /* Select Boot Size */
+#define FUSE_PSCRV   (unsigned char)~_BV(4)  /* PSCOUT Reset Value */
+#define FUSE_PSC0RB  (unsigned char)~_BV(5)  /* PSC0 Reset Behaviour */
+#define FUSE_PSC1RB  (unsigned char)~_BV(6)  /* PSC1 Reset Behaviour */
+#define FUSE_PSC2RB  (unsigned char)~_BV(7)  /* PSC2 Reset Behaviour */
+#define EFUSE_DEFAULT (FUSE_BOOTSZ0 & FUSE_BOOTSZ1)
 
 
 /* Lock Bits */
@@ -1364,4 +1383,10 @@
 #define __BOOT_LOCK_BITS_1_EXIST 
 
 
+/* Signature */
+#define SIGNATURE_0 0x1E
+#define SIGNATURE_1 0x93
+#define SIGNATURE_2 0x83
+
+
 #endif /* _AVR_IO90PWM3B_H_ */
