@@ -29,7 +29,7 @@
   POSSIBILITY OF SUCH DAMAGE. 
 */
 
-/* $Id: iotn88.h,v 1.2 2007/12/19 00:29:06 arcanum Exp $ */
+/* $Id: iotn88.h 2115 2010-04-05 23:19:53Z arcanum $ */
 
 /* avr/iotn88.h - definitions for ATtiny88 */
 
@@ -240,7 +240,7 @@
 #define CS00 0
 #define CS01 1
 #define CS02 2
-#define CTC0 7
+#define CTC0 3
 
 #define TCNT0 _SFR_IO8(0x26)
 #define TCNT0_0 0
@@ -331,7 +331,6 @@
 #define SE 0
 #define SM0 1
 #define SM1 2
-#define SM2 3
 
 #define MCUSR _SFR_IO8(0x34)
 #define PORF 0
@@ -445,7 +444,10 @@
 #define OCIE1B 2
 #define ICIE1 5
 
-#define ADC _SFR_MEM16(0x78)
+#ifndef __ASSEMBLER__
+#define ADC     _SFR_MEM16(0x78)
+#endif
+#define ADCW    _SFR_MEM16(0x78)
 
 #define ADCL _SFR_MEM8(0x78)
 #define ADCL0 0
@@ -490,7 +492,6 @@
 #define MUX3 3
 #define ADLAR 5
 #define REFS0 6
-#define REFS1 7
 
 #define DIDR0 _SFR_MEM8(0x7E)
 #define ADC0D 0
@@ -505,7 +506,6 @@
 #define DIDR1 _SFR_MEM8(0x7F)
 #define AIN0D 0
 #define AIN1D 1
-#define AREFD 2
 
 #define TCCR1A _SFR_MEM8(0x80)
 #define WGM10 0
@@ -704,49 +704,55 @@
 #define _VECTORS_SIZE 40
 
 
-/* Memory Sizes */
-#define RAMEND                0x1FF
-#define XRAMEND               0x00
-#define E2END                 0x3F
-#define FLASHEND              0x1FFF
-#define SPM_PAGESIZE          32
+/* Constants */
+#define RAMEND       0x1FF
+#define RAMSTART     (0x100)
+#define XRAMSIZE     0
+#define XRAMEND      RAMEND
+#define E2END        0x3F
+#define E2PAGESIZE   4
+#define FLASHEND     0x1FFF
+#define SPM_PAGESIZE 32
 
 
 /* Fuse Information */
-
 #define FUSE_MEMORY_SIZE 3
 
 /* Low Fuse Byte */
-#define CKSEL0 ~_BV(0) /* Select Clock Source */
-#define CKSEL1 ~_BV(1) /* Select Clock Source */
-#define CKSEL2 ~_BV(2) /* Select Clock Source */
-#define CKSEL3 ~_BV(3) /* Select Clock Source */
-#define SUT0   ~_BV(4) /* Select start-up time */
-#define SUT1   ~_BV(5) /* Select start-up time */
-#define CKOUT  ~_BV(6) /* Clock output */
-#define CKDIV8 ~_BV(7) /* Divide clock by 8 */
-#define LFUSE_DEFAULT (CKSEL0 & CKSEL2 & CKSEL3 & SUT0 & CKDIV8)
-
+#define FUSE_CKSEL0 (unsigned char)~_BV(0) /* Select Clock Source */
+#define FUSE_CKSEL1 (unsigned char)~_BV(1) /* Select Clock Source */
+#define FUSE_CKSEL2 (unsigned char)~_BV(2) /* Select Clock Source */
+#define FUSE_CKSEL3 (unsigned char)~_BV(3) /* Select Clock Source */
+#define FUSE_SUT0   (unsigned char)~_BV(4) /* Select start-up time */
+#define FUSE_SUT1   (unsigned char)~_BV(5) /* Select start-up time */
+#define FUSE_CKOUT  (unsigned char)~_BV(6) /* Clock output */
+#define FUSE_CKDIV8 (unsigned char)~_BV(7) /* Divide clock by 8 */
+#define LFUSE_DEFAULT (FUSE_CKSEL0 & FUSE_CKSEL2 & FUSE_CKSEL3 & FUSE_SUT0 & FUSE_CKDIV8)
 
 /* High Fuse Byte */
-#define BODLEVEL0   ~_BV(0) /* Brown-out Detector trigger level */
-#define BODLEVEL1   ~_BV(1) /* Brown-out Detector trigger level */
-#define BODLEVEL2   ~_BV(2) /* Brown-out Detector trigger level */
-#define EESAVE      ~_BV(3) /* EEPROM memory is preserved through chip erase */
-#define WDTON       ~_BV(4) /* Watchdog Timer Always On */
-#define SPIEN       ~_BV(5) /* Enable Serial programming and Data Downloading */
-#define DWEN        ~_BV(6) /* debugWIRE Enable */
-#define RSTDISBL    ~_BV(7) /* External reset disable */
-#define HFUSE_DEFAULT (SPIEN)    
+#define FUSE_BODLEVEL0   (unsigned char)~_BV(0) /* Brown-out Detector trigger level */
+#define FUSE_BODLEVEL1   (unsigned char)~_BV(1) /* Brown-out Detector trigger level */
+#define FUSE_BODLEVEL2   (unsigned char)~_BV(2) /* Brown-out Detector trigger level */
+#define FUSE_EESAVE      (unsigned char)~_BV(3) /* EEPROM memory is preserved through chip erase */
+#define FUSE_WDTON       (unsigned char)~_BV(4) /* Watchdog Timer Always On */
+#define FUSE_SPIEN       (unsigned char)~_BV(5) /* Enable Serial programming and Data Downloading */
+#define FUSE_DWEN        (unsigned char)~_BV(6) /* debugWIRE Enable */
+#define FUSE_RSTDISBL    (unsigned char)~_BV(7) /* External reset disable */
+#define HFUSE_DEFAULT (FUSE_SPIEN)    
 
 /* Extended Fuse Byte */
-#define SELFPRGEN   ~_BV(0) /* Self Programming Enable */
+#define FUSE_SELFPRGEN   ~_BV(0) /* Self Programming Enable */
 #define EFUSE_DEFAULT (0xFF)
 
 
-
 /* Lock Bits */
 #define __LOCK_BITS_EXIST
 
 
+/* Signature */
+#define SIGNATURE_0 0x1E
+#define SIGNATURE_1 0x93
+#define SIGNATURE_2 0x11
+
+
 #endif /* _AVR_IOTN88_H_ */
