@@ -30,7 +30,7 @@
   POSSIBILITY OF SUCH DAMAGE.
 */
 
-/* $Id: vfscanf.c,v 1.13.4.1 2008/02/23 08:58:35 dmix Exp $ */
+/* $Id: vfscanf.c 1944 2009-04-01 23:12:20Z arcanum $ */
 
 #include <avr/pgmspace.h>
 #include <ctype.h>
@@ -41,7 +41,7 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-
+#include "sectionname.h"
 #include "stdio_private.h"
 
 #if	!defined (SCANF_LEVEL)
@@ -157,6 +157,7 @@ typedef unsigned char width_t;
 /* Add noinline attribute to avoid GCC 4.2 optimization.	*/
 
 __attribute__((noinline))
+ATTRIBUTE_CLIB_SECTION
 static void putval (void *addr, long val, unsigned char flags)
 {
     if (!(flags & FL_STAR)) {
@@ -186,6 +187,7 @@ static void putval (void *addr, long val, unsigned char flags)
 }
 
 __attribute__((noinline))
+ATTRIBUTE_CLIB_SECTION
 static unsigned long
 mulacc (unsigned long val, unsigned char flags, unsigned char c)
 {
@@ -232,6 +234,7 @@ mulacc (unsigned long val, unsigned char flags, unsigned char c)
 }
 
 __attribute__((noinline))
+ATTRIBUTE_CLIB_SECTION
 static unsigned char
 conv_int (FILE *stream, width_t width, void *addr, unsigned char flags)
 {
@@ -305,6 +308,7 @@ conv_int (FILE *stream, width_t width, void *addr, unsigned char flags)
 
 #if  SCANF_BRACKET
 __attribute__((noinline))
+ATTRIBUTE_CLIB_SECTION
 static const char *
 conv_brk (FILE *stream, width_t width, char *addr, const char *fmt)
 {
@@ -403,6 +407,7 @@ PROGMEM static const char pstr_nfinity[] = "nfinity";
 PROGMEM static const char pstr_an[] = "an";
 
 __attribute__((noinline))
+ATTRIBUTE_CLIB_SECTION
 static unsigned char conv_flt (FILE *stream, width_t width, float *addr)
 {
     union {
@@ -548,6 +553,7 @@ static unsigned char conv_flt (FILE *stream, width_t width, float *addr)
 #endif	/* SCANF_FLOAT	*/
 
 __attribute__((noinline))
+ATTRIBUTE_CLIB_SECTION
 static int skip_spaces (FILE *stream)
 {
     int i;
@@ -692,6 +698,7 @@ static int skip_spaces (FILE *stream)
      -Wl,-u,vfscanf -lscanf_min -lm
      \endcode
 */
+ATTRIBUTE_CLIB_SECTION
 int vfscanf (FILE * stream, const char *fmt, va_list ap)
 {
     unsigned char nconvs;
